import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataOktaUserConfig extends cdktf.TerraformMetaArguments {
    /**
    * Retrieve a single user based on their id
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/d/user#user_id DataOktaUser#user_id}
    */
    readonly userId?: string;
    /**
    * search block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/d/user#search DataOktaUser#search}
    */
    readonly search?: DataOktaUserSearch[] | cdktf.IResolvable;
}
export interface DataOktaUserSearch {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/d/user#comparison DataOktaUser#comparison}
    */
    readonly comparison?: string;
    /**
    * Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/d/user#name DataOktaUser#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/d/user#value DataOktaUser#value}
    */
    readonly value: string;
}
export declare function dataOktaUserSearchToTerraform(struct?: DataOktaUserSearch | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/okta/d/user okta_user}
*/
export declare class DataOktaUser extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "okta_user";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/okta/d/user okta_user} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataOktaUserConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataOktaUserConfig);
    get adminRoles(): string[];
    get city(): string;
    get costCenter(): string;
    get countryCode(): string;
    get customProfileAttributes(): string;
    get department(): string;
    get displayName(): string;
    get division(): string;
    get email(): string;
    get employeeNumber(): string;
    get firstName(): string;
    get groupMemberships(): string[];
    get honorificPrefix(): string;
    get honorificSuffix(): string;
    get id(): string;
    get lastName(): string;
    get locale(): string;
    get login(): string;
    get manager(): string;
    get managerId(): string;
    get middleName(): string;
    get mobilePhone(): string;
    get nickName(): string;
    get organization(): string;
    get postalAddress(): string;
    get preferredLanguage(): string;
    get primaryPhone(): string;
    get profileUrl(): string;
    get secondEmail(): string;
    get state(): string;
    get status(): string;
    get streetAddress(): string;
    get timezone(): string;
    get title(): string;
    private _userId?;
    get userId(): string;
    set userId(value: string);
    resetUserId(): void;
    get userIdInput(): string | undefined;
    get userType(): string;
    get zipCode(): string;
    private _search?;
    get search(): DataOktaUserSearch[] | cdktf.IResolvable;
    set search(value: DataOktaUserSearch[] | cdktf.IResolvable);
    resetSearch(): void;
    get searchInput(): cdktf.IResolvable | DataOktaUserSearch[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
